@@ -5,7 +5,7 @@
   Copyright (C) 1999-2000   by Matthias Kiefer <matthias.kiefer@gmx.de>
                 2001-2005   by Stanislav Visnovsky <visnovsky@kde.org>
                 2006        by Nicolas Goutte <goutte@kde.org>
-                2007-2009   by Nick Shaforostoff <shafff@ukr.net>
+                2007-2012   by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,8 +44,8 @@
 #include "gettextstorage.h"
 #include "gettextimport.h"
 #include "gettextexport.h"
-
 #include "xliffstorage.h"
+#include "tsstorage.h"
 
 #include "mergecatalog.h"
 
@@ -68,7 +68,7 @@
 #include <ktemporaryfile.h>
 
 
-static const char* const extensions[]={".po",".pot",".xlf"};
+static const char* const extensions[]={".po",".pot",".xlf", ".ts"};
 
 static const char* const xliff_states[]={
         I18N_NOOP("New"),I18N_NOOP("Needs translation"),I18N_NOOP("Needs full localization"),I18N_NOOP("Needs adaptation"),I18N_NOOP("Translated"),
@@ -140,6 +140,8 @@ void Catalog::clear()
 
     while (!d->_altTransCatalogs.isEmpty())
         d->_altTransCatalogs.takeFirst()->deleteLater();
+    
+    d->_altTranslations.clear();
 /*
     d->msgidDiffList.clear();
     d->msgstr2MsgidDiffList.clear();
@@ -261,6 +263,11 @@ void Catalog::attachAltTransCatalog(Catalog* altCat)
         kWarning()<<altCat->url().prettyUrl()<<"has different number of entries";
 }
 
+void Catalog::attachAltTrans(int entry, const AltTrans& trans)
+{
+    d->_altTranslations.insert(entry, trans);
+}
+
 QVector<AltTrans> Catalog::altTrans(const DocPosition& pos) const
 {
     QVector<AltTrans> result;
@@ -290,6 +297,8 @@ QVector<AltTrans> Catalog::altTrans(const DocPosition& pos) const
             result.last().origin=altCat->url().prettyUrl();
         }
     }
+    if (d->_altTranslations.contains(pos.entry))
+        result<<d->_altTranslations.value(pos.entry);
     return result;
 }
 
@@ -480,22 +489,18 @@ KAutoSaveFile* Catalog::checkAutoSave(const KUrl& url)
 {
     KAutoSaveFile* autoSave=0;
     QList<KAutoSaveFile*> staleFiles = KAutoSaveFile::staleFiles(url);
-    if (!staleFiles.isEmpty())
+    foreach (KAutoSaveFile *stale, staleFiles)
     {
-        foreach (KAutoSaveFile *stale, staleFiles)
+        if (stale->open(QIODevice::ReadOnly) && !autoSave)
         {
-            if (stale->open(QIODevice::ReadOnly) && !autoSave)
-            {
-                autoSave=stale;
-                autoSave->setParent(this);
-            }
-            else
-                stale->deleteLater();
+            autoSave=stale;
+            autoSave->setParent(this);
         }
+        else
+            stale->deleteLater();
     }
-    qWarning()<<"autoSave"<<autoSave;
     if (autoSave)
-        qWarning()<<"autoSave"<<autoSave->fileName();
+        kWarning()<<"autoSave"<<autoSave->fileName();
     return autoSave;
 }
 
@@ -527,10 +532,13 @@ int Catalog::loadFromUrl(const KUrl& url, const KUrl& saidUrl, int* fileSize)
         return ISNTREADABLE;//TODO
 
     CatalogStorage* storage=0;
-    if (url.fileName().endsWith(".po")||url.fileName().endsWith(".pot"))
+    const QString& fileName=url.fileName();
+    if (fileName.endsWith(".po")||fileName.endsWith(".pot"))
         storage=new GettextCatalog::GettextStorage;
-    else if (url.fileName().endsWith(".xlf")||url.fileName().endsWith(".xliff"))
+    else if (fileName.endsWith(".xlf")||fileName.endsWith(".xliff"))
         storage=new XliffStorage;
+    else if (fileName.endsWith(".ts"))
+        storage=new TsStorage;
     else
     {
         //try harder
@@ -851,6 +859,12 @@ InlineTag Catalog::targetDeleteTag(const DocPosition& pos)
     return tag;
 }
 
+void Catalog::setTarget(DocPosition pos, const CatalogString& s)
+{
+    //TODO for case of markup present
+    m_storage->setTarget(pos, s.string);
+}
+
 TargetState Catalog::setState(const DocPosition& pos, TargetState state)
 {
     bool extendedStates=m_storage->capabilities()&ExtendedStates;
@@ -978,6 +992,12 @@ bool isApproved(TargetState state, ProjectLocal::PersonRole role)
     return state>=marginStates[role];
 }
 
+bool isApproved(TargetState state)
+{
+    static const TargetState marginStates[]={Translated, Final, SignedOff};
+    return state==marginStates[0] || state==marginStates[1] || state==marginStates[2];
+}
+
 TargetState closestState(bool approved, ProjectLocal::PersonRole role)
 {
     static const TargetState approvementStates[][3]={
@@ -988,4 +1008,13 @@ TargetState closestState(bool approved, ProjectLocal::PersonRole role)
 }
 
 
+bool Catalog::isObsolete(int entry) const
+{
+    if (KDE_ISUNLIKELY( !m_storage ))
+        return false;
+
+    return m_storage->isObsolete(entry);
+}
+
+
 #include "catalog.moc"
