@@ -31,6 +31,7 @@
 
 #include <QApplication>
 #include <QFontMetrics>
+#include <kcolorscheme.h>
 
 #define DYNAMICFILTER_LIMIT 256
 
@@ -130,7 +131,20 @@ QVariant CatalogTreeModel::data(const QModelIndex& index, int role) const
             return font;
         }
     }
-    if (role==Qt::UserRole)
+    else if (role==Qt::ForegroundRole)
+    {
+       if (m_catalog->isBookmarked(index.row()))
+       {
+           static KColorScheme colorScheme(QPalette::Normal);
+           return colorScheme.foreground(KColorScheme::LinkText);
+       }
+       if (m_catalog->isObsolete(index.row()))
+       {
+           static KColorScheme colorScheme(QPalette::Normal);
+           return colorScheme.foreground(KColorScheme::InactiveText);
+       }
+    }
+    else if (role==Qt::UserRole)
     {
         switch (index.column())
         {
