@@ -28,8 +28,6 @@
 #include "tmscanapi.h"
 #include "qaview.h"
 
-#include <iostream>
-
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QTreeView>
@@ -37,16 +35,13 @@
 #include <QSqlQuery>
 #include <QSqlRecord>
 #include <QButtonGroup>
-#include <QShortcutEvent>
 #include <QClipboard>
 #include <QShortcut>
 #include <QDragEnterEvent>
 #include <QSortFilterProxyModel>
 #include <QStyledItemDelegate>
 #include <QStringBuilder>
-#include <QPainter>
 #include <QTextDocument>
-#include <QDomDocument>
 #include <QStringBuilder>
 
 #include <KColorScheme>
@@ -56,6 +51,8 @@
 #include <kstandarddirs.h>
 #include <kxmlguifactory.h>
 #include <threadweaver/ThreadWeaver.h>
+#include <fastsizehintitemdelegate.h>
+#include <QStringListModel>
 
 
 using namespace TM;
@@ -63,88 +60,6 @@ using namespace TM;
 
 //TODO do things for case when user explicitly wants to find & accel mark
 
-void FastSizeHintItemDelegate::reset()
-{
-    cache.clear();
-}
-
-QSize FastSizeHintItemDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
-{
-    int lineCount=1;
-    int nPos=20;
-    if (index.column()!=TMDBModel::Filepath && index.column()!=TMDBModel::TransationStatus)
-    {
-        QString text=index.data().toString();
-        nPos=text.indexOf('\n');
-        if (nPos==-1)
-            nPos=text.size();
-        else
-            lineCount+=text.count('\n');
-    }
-    static QFontMetrics metrics(option.font);
-    return QSize(metrics.averageCharWidth()*nPos, metrics.height()*lineCount);
-}
-
-void FastSizeHintItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
-{
-    painter->save();
-
-    const KColorScheme& scheme=activeScheme;
-    //painter->save();
-    painter->setClipping(true);
-    painter->setClipRect(option.rect);
-    QBrush bgBrush;
-    if (option.state&QStyle::State_MouseOver)
-        bgBrush=scheme.background(KColorScheme::LinkBackground);
-    else if (index.row()%2)
-        bgBrush=scheme.background(KColorScheme::AlternateBackground);
-    else
-        bgBrush=scheme.background(KColorScheme::NormalBackground);
-    
-    painter->fillRect(option.rect, bgBrush);
-    painter->setClipRect(option.rect.adjusted(0,0,-2,0));
-    //painter->setFont(option.font);
-
-    RowColumnUnion rc;
-    rc.index.row=index.row();
-    rc.index.column=index.column();
-    //TMDBModel* m=static_cast<const TMDBModel*>(index.model());
-    if (!cache.contains(rc.v))
-    {
-        QString text=index.data(TMDBModel::HtmlDisplayRole).toString();
-        cache.insert(rc.v, new QStaticText(text));
-        cache.object(rc.v)->setTextFormat(index.column()<TMDBModel::Context?Qt::RichText:Qt::PlainText);
-    }
-    int rectWidth=option.rect.width();
-    QStaticText* staticText=cache.object(rc.v);
-    //staticText->setTextWidth(rectWidth-4);
-    QPoint textStartPoint=option.rect.topLeft();
-    textStartPoint.rx()+=2;
-    painter->drawStaticText(textStartPoint, *staticText);
-
-
-    if (staticText->size().width()<=rectWidth-4)
-    {
-        painter->restore();
-        return;
-    }
-
-    painter->setPen(bgBrush.color());
-    QPoint p1=option.rect.topRight();
-    QPoint p2=option.rect.bottomRight();
-    int limit=qMin(8, rectWidth-2);
-    int i=limit;
-    while(--i>0)
-    {
-        painter->setOpacity(float(i)/limit);
-        painter->drawLine(p1, p2);
-        p1.rx()--;
-        p2.rx()--;
-    }
-    painter->restore();
-}
-
-
 //BEGIN TMDBModel
 TMDBModel::TMDBModel(QObject* parent)
     : QSqlQueryModel(parent)
@@ -271,7 +186,7 @@ int TMDBModel::translationStatus(const QModelIndex& item) const
 #define TM_DELIMITER '\v'
 QVariant TMDBModel::data(const QModelIndex& item, int role) const
 {
-    bool doHtml=(role==HtmlDisplayRole);
+    bool doHtml=(role==FastSizeHintItemDelegate::HtmlDisplayRole);
     if (doHtml)
         role=Qt::DisplayRole;
     else if (role==Qt::FontRole && item.column()==TMDBModel::Target) //TODO Qt::ForegroundRole -- brush for orphaned entries
@@ -314,10 +229,7 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
     }
     else if (item.column()==TMDBModel::Filepath)
     {
-        QString path=result.toString();
-        QString pDir=Project::instance()->projectDir();
-        if (path.contains(pDir))//TODO cache projectDir?
-            return KUrl::relativePath(pDir,path).mid(2);
+        return shorterFilePath(result.toString());
     }
     else if (item.column()==TMDBModel::TransationStatus)
     {
@@ -327,15 +239,7 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
         return statuses[translationStatus(item)];
     }
     if (doHtml && item.column()<TMDBModel::Context)
-    {
-        QString r=result.toString();
-        if (r.isEmpty())
-            return r;
-        r=Qt::convertFromPlainText(r); //FIXME use another routine (this has bugs)
-        if (item.column()==TMDBModel::Target && !rowIsApproved(item.row()))
-            r="<p><i>" % r.mid(3, r.length()-3) % "</i></p>";
-        return r;
-    }
+        return convertToHtml(result.toString(), item.column()==TMDBModel::Target && !rowIsApproved(item.row()));
     else
         return result;
 }
@@ -360,6 +264,7 @@ protected:
 private:
     QVector<Rule> m_rules;
     mutable QMap<int,int> m_matchingRulesForSourceRow;
+    //mutable QMap<int, QVector<StartLen> > m_highlightDataForSourceRow;
 };
 
 bool TMResultsSortFilterProxyModel::lessThan(const QModelIndex& left, const QModelIndex& right) const
@@ -396,6 +301,7 @@ void TMResultsSortFilterProxyModel::fetchMore(const QModelIndex& parent)
 void TMResultsSortFilterProxyModel::setRules(const QVector<Rule>& rules)
 {
     m_rules=rules;
+    m_matchingRulesForSourceRow.clear();
     invalidateFilter();
 }
 
@@ -403,7 +309,7 @@ QVariant TMResultsSortFilterProxyModel::data(const QModelIndex& index, int role)
 {
     QVariant result=QSortFilterProxyModel::data(index, role);
 
-    if (m_rules.isEmpty() || role!=TMDBModel::HtmlDisplayRole)
+    if (m_rules.isEmpty() || role!=FastSizeHintItemDelegate::HtmlDisplayRole)
         return result;
 
     if (index.column()!=TMDBModel::Source && index.column()!=TMDBModel::Target)
@@ -411,6 +317,7 @@ QVariant TMResultsSortFilterProxyModel::data(const QModelIndex& index, int role)
 
     int source_row=mapToSource(index).row();
     QString string=result.toString();
+
     QVector<QRegExp> regExps;
     if (index.column()==TMDBModel::Source)
         regExps=m_rules[m_matchingRulesForSourceRow[source_row]].sources;
@@ -424,6 +331,8 @@ QVariant TMResultsSortFilterProxyModel::data(const QModelIndex& index, int role)
             return string.replace(pos, re.matchedLength(), "<b>" % re.cap(0) % "</b>");
     }
 
+    //StartLen sl=m_highlightDataForSourceRow.value(source_row).at(index.column());
+
     return result;
 }
     
@@ -435,25 +344,41 @@ bool TMResultsSortFilterProxyModel::filterAcceptsRow(int source_row, const QMode
     QString source=sourceModel()->index(source_row, TMDBModel::Source, source_parent).data().toString();
     QString target=sourceModel()->index(source_row, TMDBModel::Target, source_parent).data().toString();
 
-    bool accept=false;
-    int i=0;
-    for(QVector<Rule>::const_iterator it=m_rules.constBegin();it!=m_rules.constEnd();it++)
-    {
-        if (it->sources.first().indexIn(source)!=-1)
-        {
-            if (it->falseFriends.first().indexIn(target)!=-1)
-            {
-                accept=true;
-                m_matchingRulesForSourceRow[source_row]=i;
-                break;
-            }
-        }
-        i++;
-    }
+    static QVector<StartLen> dummy_positions;
+    int i=findMatchingRule(m_rules, source, target, dummy_positions);
+    bool accept=(i!=-1);
+    if (accept)
+        m_matchingRulesForSourceRow[source_row]=i;
+
     return accept;
 }
 //END TMResultsSortFilterProxyModel
 
+class QueryStylesModel: public QStringListModel
+{
+public:
+    explicit QueryStylesModel(QObject* parent = 0);
+    QVariant data(const QModelIndex& item, int role) const;
+};
+
+QueryStylesModel::QueryStylesModel(QObject* parent): QStringListModel(parent)
+{
+    setStringList(QStringList(i18n("Substring"))<<i18n("Google-like")<<i18n("Wildcard"));
+}
+
+QVariant QueryStylesModel::data(const QModelIndex& item, int role) const
+{
+    if (role==Qt::ToolTipRole)
+    {
+        static QString tooltips[]={i18n("Case insensitive"),
+                                   i18n("Space is AND operator. Case insensitive."),
+                                   i18n("Shell globs (* and ?). Case sensitive.")};
+        return tooltips[item.row()];
+    }
+    return QStringListModel::data(item, role);
+}
+
+
 //BEGIN TMWindow
 TMTab::TMTab(QWidget *parent)
     : LokalizeSubwindowBase2(parent)
@@ -519,7 +444,16 @@ TMTab::TMTab(QWidget *parent)
     view->setColumnHidden(TMDBModel::_SourceAccel,true);
     view->setColumnHidden(TMDBModel::_TargetAccel,true);
     view->setColumnHidden(TMDBModel::_Bits,true);
-    view->setItemDelegate(new FastSizeHintItemDelegate(this));
+
+    QVector<bool> singleLineColumns(TMDBModel::ColumnCount, false);
+    singleLineColumns[TMDBModel::Filepath]=true;
+    singleLineColumns[TMDBModel::TransationStatus]=true;
+    singleLineColumns[TMDBModel::Context]=true;
+
+    QVector<bool> richTextColumns(TMDBModel::ColumnCount, false);
+    richTextColumns[TMDBModel::Source]=true;
+    richTextColumns[TMDBModel::Target]=true;
+    view->setItemDelegate(new FastSizeHintItemDelegate(this,singleLineColumns,richTextColumns));
     connect(m_model,SIGNAL(resultsFetched()),view->itemDelegate(),SLOT(reset()));
     connect(m_model,SIGNAL(modelReset()),view->itemDelegate(),SLOT(reset()));
     //connect(m_model,SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),view->itemDelegate(),SLOT(reset()));
@@ -530,11 +464,8 @@ TMTab::TMTab(QWidget *parent)
     connect(m_model,SIGNAL(resultsFetched()),this,SLOT(handleResults()));
     connect(m_model,SIGNAL(finalResultCountFetched(int)),this,SLOT(displayTotalResultCount()));
 
-    QButtonGroup* btnGrp=new QButtonGroup(this);
-    btnGrp->addButton(ui_queryOptions->substr,(int)TMDBModel::SubStr);
-    btnGrp->addButton(ui_queryOptions->like,(int)TMDBModel::WordOrder);
-    btnGrp->addButton(ui_queryOptions->glob,(int)TMDBModel::Glob);
-    connect(btnGrp,SIGNAL(buttonClicked(int)),m_model,SLOT(setQueryType(int)));
+    ui_queryOptions->queryStyle->setModel(new QueryStylesModel(this));
+    connect(ui_queryOptions->queryStyle,SIGNAL(currentIndexChanged(int)),m_model,SLOT(setQueryType(int)));
 
     ui_queryOptions->dbName->setModel(DBFilesModel::instance());
     ui_queryOptions->dbName->setRootModelIndex(DBFilesModel::instance()->rootIndex());
@@ -547,6 +478,13 @@ TMTab::TMTab(QWidget *parent)
     connect(ui_queryOptions->dbName, SIGNAL(activated(QString)), m_model, SLOT(setDB(QString)));
     //connect(ui_queryOptions->dbName, SIGNAL(activated(QString)), this, SLOT(performQuery()));
 
+//BEGIN resizeColumnToContents
+    static const int maxInitialWidths[4]={QApplication::desktop()->availableGeometry().width()/3,QApplication::desktop()->availableGeometry().width()/3, 50, 200};
+    int column=sizeof(maxInitialWidths)/sizeof(int);
+    while (--column>=0)
+        view->setColumnWidth(column, maxInitialWidths[column]);
+
+//END resizeColumnToContents
     
     int i=6;
     while (--i>ID_STATUS_PROGRESS)
@@ -568,7 +506,6 @@ TMTab::TMTab(QWidget *parent)
     addDockWidget(Qt::RightDockWidgetArea, m_qaView);
     tm->addAction( QLatin1String("showqa_action"), m_qaView->toggleViewAction() );
 
-
     connect(m_qaView, SIGNAL(rulesChanged()), this, SLOT(setQAMode()));
     connect(m_qaView->toggleViewAction(), SIGNAL(toggled(bool)), this, SLOT(setQAMode(bool)));
 
@@ -643,30 +580,8 @@ void TMTab::handleResults()
     }
     kDebug()<<"=DocPosition::UndefPart";
     m_partToAlsoTryLater=DocPosition::UndefPart;
-
-//BEGIN resizeColumnToContents
-    QTreeView* view=ui_queryOptions->treeView;
-    static const int maxInitialWidths[4]={QApplication::desktop()->availableGeometry().width()/3,QApplication::desktop()->availableGeometry().width()/3, 50, 200};
-    int column=sizeof(maxInitialWidths)/sizeof(int);
-    while (--column>=0)
-    {
-        //view->resizeColumnToContents(i);
-        /*
-        int max=0;
-        int count=qMin(rowCount, 32);
-        for (int row=0;row<count;++row)
-        {
-            int w = view->itemDelegate()->sizeHint(QStyleOptionViewItemV2(),m_model->index(row,column)).width();
-            if (w>max)
-                max=w;
-        }
-        if (count) //qWarning()<<(sum/count);
-            view->setColumnWidth(column, qMin(max, maxInitialWidths[column]));
-        */
-        view->setColumnWidth(column, maxInitialWidths[column]);
-    }
-    view->setFocus();
-//END resizeColumnToContents
+    
+    ui_queryOptions->treeView->setFocus();
 }
 
 void TMTab::displayTotalResultCount()
@@ -706,6 +621,8 @@ void TMTab::openFile()
 
 void TMTab::setQAMode(bool enable)
 {
+    static_cast<FastSizeHintItemDelegate*>(ui_queryOptions->treeView->itemDelegate())->reset();
+
     if (!enable)
     {
         m_proxyModel->setRules(QVector<Rule>());
@@ -713,7 +630,6 @@ void TMTab::setQAMode(bool enable)
     }
 
     m_proxyModel->setRules(m_qaView->rules());
-    static_cast<FastSizeHintItemDelegate*>(ui_queryOptions->treeView->itemDelegate())->reset();
 
     /*QDomElement docElem = m_categories.at(0).toElement();
 
@@ -724,7 +640,7 @@ void TMTab::setQAMode(bool enable)
         qDebug() << e.tagName();
         n = n.nextSiblingElement();
     }*/
-    
+
     performQuery();
 }
 
@@ -823,7 +739,7 @@ void TMTab::lookup(QString source, QString target)
     ui_queryOptions->queryTarget->setText(target);
     ui_queryOptions->invertSource->setChecked(false);
     ui_queryOptions->invertTarget->setChecked(false);
-    ui_queryOptions->substr->click();
+    ui_queryOptions->queryStyle->setCurrentIndex(TMDBModel::SubStr);
     performQuery();
 }
 
@@ -834,7 +750,7 @@ void TMTab::lookup(QString source, QString target)
 
 bool TMTab::findGuiTextPackage(QString text, QString package)
 {
-    std::cout<<package.toLatin1().constData()<<text.toLatin1().constData()<<std::endl;
+    //std::cout<<package.toLatin1().constData()<<text.toLatin1().constData()<<std::endl;
     kWarning()<<package<<text;
     KLineEdit* const source_target_query[]={ui_queryOptions->queryTarget,ui_queryOptions->querySource};
     static const DocPosition::Part source_target[]={DocPosition::Target,DocPosition::Source};
@@ -850,7 +766,7 @@ bool TMTab::findGuiTextPackage(QString text, QString package)
     ui_queryOptions->invertTarget->setChecked(false);
     if (!package.isEmpty()) package='*'+package+'*';
     ui_queryOptions->filemask->setText(package);
-    ui_queryOptions->glob->click();
+    ui_queryOptions->queryStyle->setCurrentIndex(TMDBModel::Glob);
     performQuery();
 
     return true;
