@@ -5,7 +5,7 @@
 
 use strict;
 
-### Please add your SVN account name in *alphabetical* order to the list
+### Please add your KDE (svn/git) account name in *alphabetical* order to the list
 ### below, then answer the following questions:
 ###
 ### 1. Include 'gplv23' if you are okay with contributions you've made under
@@ -26,7 +26,9 @@ use strict;
 ### For more information, see http://techbase.kde.org/Projects/KDE_Relicensing
 
 my %license_table = (
+    'hubner'    => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'aacid'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
+    'abryant'   => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'adawit'    => ['gplv23', 'lgplv23',                      '+eV' ],
     'alund'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'amth'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
@@ -60,17 +62,20 @@ my %license_table = (
     'haeber'    => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'haeckel'   => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+',       ],
     'hdhoang'   => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
+    'hindenburg'=> ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'hoelzer'   => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'garbanzo'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'giannaros' => ['gplv23', 'lgplv23'                             ],
     'ilic'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'jbrouault' => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'jehrichs'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
+    'jekyllwu'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'jlee'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'jones'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'jowenn'    => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'kloecker'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'kossebau'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
+    'kylafas'   => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'mbritton'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
  'michaelhowell'=> ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'mirko'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
@@ -88,6 +93,7 @@ my %license_table = (
     'pletourn'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'pupeno'    => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'raabe'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
+    'ralfjung'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'reiher'    => ['gplv23', 'lgplv23',                      '+eV' ],
     'robbilla'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
    'rpreukschas'=> ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
@@ -252,6 +258,12 @@ my %license_table = (
     # Do not add anything here. Use the first half of the table.
 );
 
+my %secondary_mail_addresses = (
+    'aleixpol@kde.org' => 'apol',
+    'devel@the-user.org' => 'schmidt-domine',
+    'git@the-user.org' => 'schmidt-domine',
+);
+
 my %ruletable;
 my %blacklist;
 my %whitelist;
@@ -263,15 +275,74 @@ foreach my $who (keys %license_table) {
     }
 }
 
+# Read kde-common/accounts for email->name mapping.
+
+my $configfile = $ENV{HOME}. "/.config/KDE/relicensecheck.conf";
+
+open(CONFIG, $configfile) or die "Please write the path to kde-common/accounts in $configfile";
+my $accountfile;
+while (<CONFIG>) {
+    if (not /^#/) {
+        chomp;
+        $accountfile = $_;
+    }
+}
+close CONFIG;
+defined $accountfile or die "Please write the path to kde-common/accounts in $configfile";
+
+my %authors = ();
+if ($accountfile) {
+    open(ACCOUNTS, $accountfile) || die "Account file not found: $accountfile";
+    while (<ACCOUNTS>) {
+        # The format is nick name email.
+        if (/([^\s]*)\s+([^\s].*[^\s])\s+([^\s]+)/) {
+            $authors{$3} = "$1";
+        }
+        #elsif (/([^\s]*)\s+([^\s]*)/) {
+        #    $authors{$1} = $2;
+        #}
+        else {
+            die "Couldn't parse $_";
+        }
+    }
+}
+
+sub resolveEmail($) {
+    my ($email) = @_;
+
+    my $resolved = $authors{$email};
+    if (not defined $resolved) {
+        $resolved = $secondary_mail_addresses{$email};
+    }
+    if (not defined $resolved) {
+        print STDERR "Could not find $email in $accountfile\n";
+        return $email;
+    }
+    return $resolved;
+}
+
 my $file = $ARGV[0] || "";
 
 die "need existing file: $file" if (! -r $file);
 
-open(IN, "-|") || exec 'svn', 'log', '-q', $file;
+my $svn = (-d ".svn");
+
+if ($svn) {
+    open(IN, "-|") || exec 'svn', 'log', '-q', $file;
+} else {
+    # Format the git output to match the format of svn log.
+    open(IN, "-|") || exec 'git', 'log', '--abbrev-commit', '--pretty=format:r%h | %ae ', $file;
+}
 while(<IN>) {
 
-    if (/^r(\d+) \| (\S+) /)  {
+    if (/^r(\S+) \| (\S+) /)  {
         my ($rev, $author) = ($1, $2);
+        #print STDERR "rev=$rev author=$author\n";
+
+        if (not $svn) {
+            # Resolve email to account name
+            $author = resolveEmail($author);
+        }
 
         next if ($author eq "scripty" or $author eq "(no");
 
@@ -291,12 +362,29 @@ close(IN);
 my %loc_author = ();
 
 if (-f $file) {
-    open(IN, "-|") || exec 'svn', 'ann', '-x', '-w', $file;
-    while(<IN>) {
-        my ($author) = (split)[1];
-        $loc_author{$author}++;
+    if ($svn) {
+        open(IN, "-|") || exec 'svn', 'ann', '-x', '-w', $file;
+        while(<IN>) {
+            my ($author) = (split)[1];
+            $loc_author{$author}++;
+        }
+        close(IN);
+    } else {
+        open(IN, "-|") || exec 'git', 'blame', '-f', '-w', '-e', $file;
+        while(<IN>) {
+            # The format is:
+            # b061712b kdecore/klockfile.cpp      (<faure@kde.org>   [...]
+            if (m/^(\S+) (\S+) +\(<([^>]+)>/) {
+                my ($author) = $3;
+                next if ($author eq 'not.committed.yet');
+                $author = resolveEmail($author);
+                $loc_author{$author}++;
+            } else {
+                print STDERR "Parse error on git blame output: $_";
+            }
+        }
+        close(IN);
     }
-    close(IN);
 }
 
 if (defined (keys %blacklist)) {
@@ -305,9 +393,10 @@ if (defined (keys %blacklist)) {
     my %stat;
 
     foreach my $license(keys %blacklist) {
-        print "- $license:\n";
+        print "- $license: ". join(' ', (keys %{$blacklist{$license}})) . "\n";
         foreach my $who(keys %{$blacklist{$license}}) {
-            $stat{$license} += length(@{$blacklist{$license}->{$who}});
+            next if not defined $loc_author{$who};
+            $stat{$license} += scalar(@{$blacklist{$license}->{$who}});
             printf "%9s (%4d LOC): %s \n", $who, $loc_author{$who} || 0, join(",", @{$blacklist{$license}->{$who}});
         }
         print "\n";
