@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2011                                               *
+ *   copyright (C) 2002-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -21,6 +21,7 @@
 #include "floatingtextwidget.h"
 #include "folder.h"
 #include "forkjoinwidget.h"
+#include "layoutgenerator.h"
 #include "model_utils.h"
 #include "objectnodewidget.h"
 #include "objectwidget.h"
@@ -29,9 +30,10 @@
 #include "statewidget.h"
 #include "uml.h"
 #include "umldoc.h"
+#include "umlscene.h"
 #include "umlview.h"
-#include "umlwidget.h"
 #include "widget_utils.h"
+#include "widgetbase.h"
 
 // kde includes
 #include <klocale.h>
@@ -52,6 +54,23 @@ ListPopupMenu::ListPopupMenu(QWidget *parent, MenuType type, UMLView * view)
     m_TriggerObject.m_View = view;
     m_TriggerObjectType = tot_View;
     setupMenu(type);
+    setupActionsData();
+}
+
+/**
+ * Constructs the popup menu for a WidgetBase with customized menu type.
+ *
+ * @param parent   The parent to ListPopupMenu.
+ * @param type     The type of menu to display.
+ * @param object   The WidgetBase object.
+ */
+ListPopupMenu::ListPopupMenu(QWidget *parent, MenuType type, WidgetBase *widget)
+  : KMenu(parent)
+{
+    m_TriggerObject.m_Widget = widget;
+    m_TriggerObjectType = tot_Widget;
+    setupMenu(type);
+    setupActionsData();
 }
 
 /**
@@ -246,18 +265,19 @@ ListPopupMenu::ListPopupMenu(QWidget *parent, UMLListViewItem::ListViewType type
         break;
     }
     setupMenu(mt);
+    setupActionsData();
 }
 
 /**
  * Constructs the popup menu for a canvas widget.
  *
  * @param parent   The parent to ListPopupMenu.
- * @param object   The UMLWidget to represent a menu for.
+ * @param object   The WidgetBase to represent a menu for.
  * @param multi    True if multiple items are selected.
  * @param unique   True if multiple selected items all have
  *                 the same type (e.g. Class, Interface)
  */
-ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
+ListPopupMenu::ListPopupMenu(QWidget * parent, WidgetBase * object,
                              bool multi, bool unique)
   : KMenu(parent)
 {
@@ -267,7 +287,7 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
     //make menu for logical view
     if (!object)
         return;
-    UMLWidget::WidgetType type = object->baseType();
+    WidgetBase::WidgetType type = object->baseType();
     // uDebug() << "ListPopupMenu created with multi=" << multi << " , unique="
     //          << unique << " for WidgetType=" << type;
 
@@ -291,7 +311,7 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
         if (unique) {
             if (type == WidgetBase::wt_Interface) {
                 insert(mt_DrawAsCircle_Selection, i18n("Draw as Circle"), CHECKABLE);
-                setActionChecked(mt_DrawAsCircle_Selection, c->getDrawAsCircle());
+                setActionChecked(mt_DrawAsCircle_Selection, c->visualProperty(ClassifierWidget::DrawAsCircle));
                 insert(mt_ChangeToClass_Selection, i18n("Change into Class"));
             } else if (type == WidgetBase::wt_Class) {
                 UMLClassifier *umlc = c->classifier();
@@ -362,10 +382,10 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
 
     case WidgetBase::wt_Object:
         {
-            UMLView * pView = static_cast<UMLView *>(parent);
             //Used for sequence diagram and collaboration diagram widgets
             insertSubMenuColor( object->useFillColor() );
-            if( pView->type() == Uml::DiagramType::Sequence ) {
+            if (object->umlScene() &&
+                object->umlScene()->type() == Uml::DiagramType::Sequence) {
                 addSeparator();
                 MenuType tabUp = mt_Up;
                 insert(mt_Up, Icon_Utils::SmallIcon(Icon_Utils::it_Arrow_Up), i18n("Move Up"));
@@ -415,10 +435,21 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
             }
             insertSubMenuColor( object->useFillColor() );
             insertStdItems(false, type);
-            if (pState->stateType() == StateWidget::Normal) {
-                insert(mt_Rename, i18n("Change State Name..."));
-                insert(mt_Change_Font);
-                insert(mt_Properties);
+            switch (pState->stateType()) {
+	        case StateWidget::Normal:
+                    insert(mt_Rename, i18n("Change State Name..."));
+                    insert(mt_Change_Font);
+                    insert(mt_Properties);
+		    break;
+	        case StateWidget::Fork:
+	        case StateWidget::Join:
+                    if (pState->drawVertical())
+                        insert(mt_Flip, i18n("Flip Horizontal"));
+                    else
+                        insert(mt_Flip, i18n("Flip Vertical"));
+		    break;
+		default:
+		    break;
             }
         }
         break;
@@ -426,7 +457,7 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
     case WidgetBase::wt_ForkJoin:
         {
             ForkJoinWidget *pForkJoin = static_cast<ForkJoinWidget*>(object);
-            if (pForkJoin->getDrawVertical()) {
+            if (pForkJoin->orientation() == Qt::Vertical) {
                 insert(mt_Flip, i18n("Flip Horizontal"));
             }
             else {
@@ -560,6 +591,7 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
     setActionEnabled( mt_Cut, bCutState );
     setActionEnabled( mt_Copy, bCutState );
     setActionEnabled( mt_Paste, false );
+    setupActionsData();
 }
 
 /**
@@ -903,29 +935,29 @@ void ListPopupMenu::makeMultiClassifierPopup(ClassifierWidget *c)
     if (type == WidgetBase::wt_Class) {
         cls = static_cast<ClassifierWidget*>(c);
         insert(mt_Show_Attributes_Selection, show, i18n("Attributes"), CHECKABLE);
-        setActionChecked(mt_Show_Attributes_Selection, cls->getShowAtts());
+        setActionChecked(mt_Show_Attributes_Selection, cls->visualProperty(ClassifierWidget::ShowAttributes));
     }
     insert(mt_Show_Operations_Selection, show, i18n("Operations"), CHECKABLE);
-    setActionChecked(mt_Show_Operations_Selection, c->getShowOps());
+    setActionChecked(mt_Show_Operations_Selection, c->visualProperty(ClassifierWidget::ShowOperations));
     insert(mt_Show_Public_Only_Selection, show, i18n("Public Only"), CHECKABLE);
-    setActionChecked(mt_Show_Public_Only_Selection, c->getShowPublicOnly());
+    setActionChecked(mt_Show_Public_Only_Selection, c->visualProperty(ClassifierWidget::ShowPublicOnly));
     insert(mt_Visibility_Selection, show, i18n("Visibility"), CHECKABLE);
-    setActionChecked(mt_Visibility_Selection, c->getShowVisibility());
+    setActionChecked(mt_Visibility_Selection, c->visualProperty(ClassifierWidget::ShowVisibility));
     insert(mt_Show_Operation_Signature_Selection, show, i18n("Operation Signature"), CHECKABLE);
-    bool sig = (c->operationSignatureType() == Uml::SignatureType::SigNoVis ||
-                c->operationSignatureType() == Uml::SignatureType::ShowSig);
+    bool sig = (c->operationSignature() == Uml::SignatureType::SigNoVis ||
+                c->operationSignature() == Uml::SignatureType::ShowSig);
     setActionChecked(mt_Show_Operation_Signature_Selection, sig);
     if (type == WidgetBase::wt_Class) {
         insert(mt_Show_Attribute_Signature_Selection, show, i18n("Attribute Signature"), CHECKABLE);
-        sig = (cls->attributeSignatureType() == Uml::SignatureType::SigNoVis ||
-               cls->attributeSignatureType() == Uml::SignatureType::ShowSig);
+        sig = (cls->attributeSignature() == Uml::SignatureType::SigNoVis ||
+               cls->attributeSignature() == Uml::SignatureType::ShowSig);
         setActionChecked(mt_Show_Attribute_Signature_Selection, sig);
     }
     insert(mt_Show_Packages_Selection, show, i18n("Package"), CHECKABLE);
-    setActionChecked(mt_Show_Packages_Selection, c->getShowPackage());
+    setActionChecked(mt_Show_Packages_Selection, c->visualProperty(ClassifierWidget::ShowPackage));
     if (type == WidgetBase::wt_Class) {
         insert(mt_Show_Stereotypes_Selection, show, i18n("Stereotype"), CHECKABLE);
-        setActionChecked(mt_Show_Stereotypes_Selection, cls->getShowStereotype());
+        setActionChecked(mt_Show_Stereotypes_Selection, cls->visualProperty(ClassifierWidget::ShowStereotype));
     }
     addMenu(show);
 }
@@ -952,7 +984,7 @@ void ListPopupMenu::makeClassifierPopup(ClassifierWidget *c)
     insert(mt_Change_Font);
     if (type == WidgetBase::wt_Interface) {
         insert(mt_DrawAsCircle, i18n("Draw as Circle"), CHECKABLE);
-        setActionChecked(mt_DrawAsCircle, c->getDrawAsCircle());
+        setActionChecked(mt_DrawAsCircle, c->visualProperty(ClassifierWidget::DrawAsCircle));
         insert(mt_ChangeToClass, i18n("Change into Class"));
     } else {
         insert(mt_Refactoring, Icon_Utils::SmallIcon(Icon_Utils::it_Refactor), i18n("Refactor"));
@@ -1148,14 +1180,12 @@ void ListPopupMenu::insertSubMenuNew(MenuType type)
             insert(mt_Initial_State, menu, Icon_Utils::SmallIcon(Icon_Utils::it_InitialState), i18n("Initial State"));
             insert(mt_End_State, menu, Icon_Utils::SmallIcon(Icon_Utils::it_EndState), i18n("End State"));
             insert(mt_State, menu, Icon_Utils::SmallIcon(Icon_Utils::it_UseCase), i18nc("add new state", "State..."));
-            /* Cannot add these in branches/KDE/4.8 right now due to i18n message freeze:
             insert(mt_Junction, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Junction), i18n("Junction"));
             insert(mt_DeepHistory, menu, Icon_Utils::SmallIcon(Icon_Utils::it_History_Deep), i18n("Deep History"));
             insert(mt_ShallowHistory, menu, Icon_Utils::SmallIcon(Icon_Utils::it_History_Shallow), i18n("Shallow History"));
             insert(mt_Choice, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Choice_Rhomb), i18n("Choice"));
             insert(mt_StateFork, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Fork_State), i18n("Fork"));
             insert(mt_StateJoin, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Join), i18n("Join"));
-             */
             insert(mt_FloatText, menu);
             break;
         case mt_On_Activity_Diagram:
@@ -1707,10 +1737,30 @@ void ListPopupMenu::setupDiagramMenu(UMLView* view)
     insert(mt_Clear, Icon_Utils::SmallIcon(Icon_Utils::it_Clear), i18n("Clear Diagram"));
     insert(mt_Export_Image);
     addSeparator();
+    QList<MenuType> types;
+    types << mt_Apply_Layout << mt_Apply_Layout1 << mt_Apply_Layout2 << mt_Apply_Layout3 << mt_Apply_Layout4 << mt_Apply_Layout5 << mt_Apply_Layout6 << mt_Apply_Layout7 << mt_Apply_Layout8 << mt_Apply_Layout9;
+    LayoutGenerator generator;
+    if (generator.isEnabled()) {
+        QHash<QString, QString> configFiles;
+        if (LayoutGenerator::availableConfigFiles(view->umlScene(), configFiles)) {
+            int i = 0;
+            foreach(const QString &key, configFiles.keys()) {
+                if (i >= types.size())
+                    break;
+                insert(types[i], QPixmap(), i18n("apply '%1'",configFiles[key]));
+                getAction(types[i])->setData(QVariant(key));
+                i++;
+            }
+            addSeparator();
+        }
+    }
+    else {
+        uWarning() << "Could not add autolayout entries because graphviz installation has not been found.";
+    }
     insert(mt_SnapToGrid, i18n("Snap to Grid"), CHECKABLE);
-    setActionChecked(mt_SnapToGrid, view->getSnapToGrid() );
+    setActionChecked(mt_SnapToGrid, view->umlScene()->snapToGrid() );
     insert(mt_ShowSnapGrid, i18n("Show Grid"), CHECKABLE);
-    setActionChecked(mt_ShowSnapGrid, view->getShowSnapGrid() );
+    setActionChecked(mt_ShowSnapGrid, view->umlScene()->isSnapGridVisible() );
     insert(mt_Properties);
 }
 
