@@ -14,7 +14,6 @@
 // app includes
 #include "activitydialog.h"
 #include "debug_utils.h"
-#include "docwindow.h"
 #include "listpopupmenu.h"
 #include "uml.h"
 #include "umldoc.h"
@@ -53,6 +52,14 @@ ActivityWidget::ActivityType ActivityWidget::activityType() const
     return m_activityType;
 }
 
+/**
+ * Returns the type string of activity.
+ */
+QString ActivityWidget::activityTypeStr() const
+{
+    return QLatin1String(ENUM_NAME(ActivityWidget, ActivityType, m_activityType));
+}
+
 /**
  * Sets the type of activity.
  */
@@ -100,9 +107,9 @@ bool ActivityWidget::isActivity(WorkToolBar::ToolBar_Buttons tbb,
 }
 
 /**
- * This method get the name of the preText attribute
+ * This method get the name of the preText attribute.
  */
-QString ActivityWidget::preconditionText()
+QString ActivityWidget::preconditionText() const
 {
     return m_preconditionText;
 }
@@ -114,25 +121,25 @@ void ActivityWidget::setPreconditionText(const QString& aPreText)
 {
     m_preconditionText = aPreText;
     updateComponentSize();
-    adjustAssocs( getX(), getY() );
+    adjustAssocs( x(), y() );
 }
 
 /**
- * This method get the name of the postText attribute
+ * This method get the name of the postText attribute.
  */
-QString ActivityWidget::postconditionText()
+QString ActivityWidget::postconditionText() const
 {
-    return m_postconditionText ;
+    return m_postconditionText;
 }
 
- /**
+/**
  * This method set the name of the postText attribute
  */
 void ActivityWidget::setPostconditionText(const QString& aPostText)
 {
     m_postconditionText = aPostText;
     updateComponentSize();
-    adjustAssocs( getX(), getY() );
+    adjustAssocs( x(), y() );
 }
 
 /**
@@ -141,12 +148,11 @@ void ActivityWidget::setPostconditionText(const QString& aPostText)
  */
 void ActivityWidget::showPropertiesDialog()
 {
-    DocWindow *docwindow = UMLApp::app()->docWindow();
-    docwindow->updateDocumentation(false);
+    umlScene()->updateDocumentation(false);
 
-    QPointer<ActivityDialog> dialog = new ActivityDialog(umlScene(), this);
+    QPointer<ActivityDialog> dialog = new ActivityDialog(umlScene()->view(), this);
     if (dialog->exec() && dialog->getChangesMade()) {
-        docwindow->showDocumentation(this, true);
+        umlScene()->showDocumentation(this, true);
         UMLApp::app()->document()->setModified(true);
     }
     delete dialog;
@@ -167,7 +173,7 @@ void ActivityWidget::paint(QPainter & p, int offsetX, int offsetY)
 
     switch ( m_activityType )
     {
-    case Normal :
+    case Normal:
         UMLWidget::setPenFromSettings(p);
         if ( UMLWidget::useFillColor() ) {
             p.setBrush( UMLWidget::fillColor() );
@@ -177,21 +183,20 @@ void ActivityWidget::paint(QPainter & p, int offsetX, int offsetY)
             const int fontHeight  = fm.lineSpacing();
             int textStartY = (h / 2) - (fontHeight / 2);
             p.drawRoundRect(offsetX, offsetY, w, h, (h * 60) / w, 60);
-            p.setPen(Qt::black);
+            p.setPen(textColor());
             p.setFont( UMLWidget::font() );
             p.drawText(offsetX + ACTIVITY_MARGIN, offsetY + textStartY,
                        w - ACTIVITY_MARGIN * 2, fontHeight, Qt::AlignCenter, name());
         }
         break;
 
-    case Initial :
+    case Initial:
         p.setPen( QPen(m_LineColor, 1) );
         p.setBrush( WidgetBase::lineColor() );
         p.drawEllipse( offsetX, offsetY, w, h );
         break;
 
-    case Final :
-
+    case Final:
         UMLWidget::setPenFromSettings(p);
         p.setBrush( Qt::white );
         pen.setWidth( 2 );
@@ -207,7 +212,7 @@ void ActivityWidget::paint(QPainter & p, int offsetX, int offsetY)
         }
         break;
 
-    case End :
+    case End:
         p.setPen( QPen(m_LineColor, 1) );
         p.setBrush( WidgetBase::lineColor() );
         p.drawEllipse( offsetX, offsetY, w, h );
@@ -217,7 +222,7 @@ void ActivityWidget::paint(QPainter & p, int offsetX, int offsetY)
         p.drawEllipse( offsetX + 3, offsetY + 3, w - 6, h - 6 );
         break;
 
-    case Branch :
+    case Branch:
         UMLWidget::setPenFromSettings(p);
         p.setBrush( UMLWidget::fillColor() );
         {
@@ -231,7 +236,7 @@ void ActivityWidget::paint(QPainter & p, int offsetX, int offsetY)
         }
         break;
 
-    case Invok :
+    case Invok:
         UMLWidget::setPenFromSettings(p);
         if ( UMLWidget::useFillColor() ) {
             p.setBrush( UMLWidget::fillColor() );
@@ -241,7 +246,7 @@ void ActivityWidget::paint(QPainter & p, int offsetX, int offsetY)
             const int fontHeight  = fm.lineSpacing();
             int textStartY = (h / 2) - (fontHeight / 2);
             p.drawRoundRect(offsetX, offsetY, w, h, (h * 60) / w, 60);
-            p.setPen(Qt::black);
+            p.setPen(textColor());
             p.setFont( UMLWidget::font() );
             p.drawText(offsetX + ACTIVITY_MARGIN, offsetY + textStartY,
                        w - ACTIVITY_MARGIN * 2, fontHeight, Qt::AlignCenter, name());
@@ -256,7 +261,7 @@ void ActivityWidget::paint(QPainter & p, int offsetX, int offsetY)
         p.drawLine((int)(x + 10),(int)(y + 10), (int)(x + 10), (int)(y + 20));
         break;
 
-    case Param :
+    case Param:
         UMLWidget::setPenFromSettings(p);
         if ( UMLWidget::useFillColor() ) {
             p.setBrush( UMLWidget::fillColor() );
@@ -268,7 +273,7 @@ void ActivityWidget::paint(QPainter & p, int offsetX, int offsetY)
             QString postCond= "<<postcondition>> "+postconditionText();
             //int textStartY = (h / 2) - (fontHeight / 2);
             p.drawRoundRect(offsetX, offsetY, w, h, (h * 60) / w, 60);
-            p.setPen(Qt::black);
+            p.setPen(textColor());
             p.setFont( UMLWidget::font() );
             p.drawText(offsetX + ACTIVITY_MARGIN, offsetY + fontHeight + 10,
                        w - ACTIVITY_MARGIN * 2, fontHeight, Qt::AlignCenter, preCond);
@@ -280,14 +285,14 @@ void ActivityWidget::paint(QPainter & p, int offsetX, int offsetY)
 
         break;
     }
-    if(m_selected)
+    if (m_selected)
         drawSelected(&p, offsetX, offsetY);
 }
 
 /**
  * Loads the widget from the "activitywidget" XMI element.
  */
-bool ActivityWidget::loadFromXMI( QDomElement & qElement )
+bool ActivityWidget::loadFromXMI(QDomElement& qElement)
 {
     if( !UMLWidget::loadFromXMI( qElement ) )
         return false;
