@@ -8,37 +8,36 @@
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
-// own header file
 #include "umlwidget.h"
-// qt includes
-#include <QtCore/QPointer>
-#include <QtGui/QPainter>
-#include <QtGui/QColor>
-#include <QtGui/QMouseEvent>
+
+// local includes
+#include "associationwidget.h"
+#include "classifier.h"
+#include "classpropdlg.h"
+#include "cmds.h"
+#include "debug_utils.h"
+#include "floatingtextwidget.h"
+#include "idchangelog.h"
+#include "listpopupmenu.h"
+#include "settingsdlg.h"
+#include "uml.h"
+#include "umldoc.h"
+#include "umlobject.h"
+#include "umlview.h"
+#include "umlwidgetcontroller.h"
+#include "uniqueid.h"
+
 // kde includes
 #include <kcolordialog.h>
 #include <kfontdialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-// local includes
-#include "debug_utils.h"
-#include "umlwidgetcontroller.h"
-#include "umlobject.h"
-#include "classifier.h"
-#include "uniqueid.h"
-#include "uml.h"
-#include "umldoc.h"
-#include "umlview.h"
-#include "umlclassifierlistitemlist.h"
-#include "listpopupmenu.h"
-#include "associationwidget.h"
-#include "settingsdlg.h"
-#include "codedocument.h"
-#include "floatingtextwidget.h"
-#include "docwindow.h"
-#include "classpropdlg.h"
-#include "idchangelog.h"
-#include "cmds.h"
+
+// qt includes
+#include <QtCore/QPointer>
+#include <QtGui/QPainter>
+#include <QtGui/QColor>
+#include <QtGui/QMouseEvent>
 
 using namespace Uml;
 
@@ -54,8 +53,9 @@ const UMLSceneSize UMLWidget::DefaultMaximumSize(1000, 1000);
  */
 UMLWidget::UMLWidget(UMLScene * scene, WidgetType type, UMLObject * o, UMLWidgetController *widgetController)
   : WidgetBase(scene, type),
-    UMLSceneRectItem(scene->canvas())
+    UMLSceneRectItem()
 {
+    setCanvas(scene->canvas());
     if (widgetController) {
         m_widgetController = widgetController;
     } else {
@@ -79,8 +79,9 @@ UMLWidget::UMLWidget(UMLScene * scene, WidgetType type, UMLObject * o, UMLWidget
  */
 UMLWidget::UMLWidget(UMLScene *scene, WidgetType type, Uml::IDType id, UMLWidgetController *widgetController)
   : WidgetBase(scene, type),
-    UMLSceneRectItem(scene->canvas())
+    UMLSceneRectItem()
 {
+    setCanvas(scene->canvas());
     if (widgetController) {
         m_widgetController = widgetController;
     } else {
@@ -94,7 +95,7 @@ UMLWidget::UMLWidget(UMLScene *scene, WidgetType type, Uml::IDType id, UMLWidget
 }
 
 /**
- * Standard destructor.
+ * Destructor.
  */
 UMLWidget::~UMLWidget()
 {
@@ -125,8 +126,8 @@ UMLWidget& UMLWidget::operator=(const UMLWidget & other)
     m_instanceName = other.m_instanceName;
     m_instanceName = other.m_instanceName;
     m_showStereotype = other.m_showStereotype;
-    setX(other.getX());
-    setY(other.getY());
+    setX(other.x());
+    setY(other.y());
     UMLSceneRectItem::setSize(other.width(), other.height());
 
     // assign volatile (non-saved) members
@@ -155,7 +156,7 @@ bool UMLWidget::operator==(const UMLWidget& other) const
     if (this == &other)
         return true;
 
-    if (m_Type != other.m_Type) {
+    if (m_baseType != other.m_baseType) {
         return false;
     }
 
@@ -228,8 +229,7 @@ void UMLWidget::mousePressEvent(QMouseEvent *me)
 void UMLWidget::updateWidget()
 {
     updateComponentSize();
-    adjustAssocs(getX(), getY());   //adjust assoc lines.
-    switch (m_Type) {
+    switch (m_baseType) {
     case WidgetBase::wt_Class:
         m_scene->createAutoAttributeAssociations(this);
         break;
@@ -264,6 +264,12 @@ void UMLWidget::constrain(int& width, int& height)
         width = maxSize.width();
     if (height > maxSize.height())
         height = maxSize.height();
+
+    if (fixedAspectRatio()) {
+        UMLSceneSize size = UMLSceneRectItem::size();
+        float aspectRatio = (float)size.height()/size.width();
+        height = width * aspectRatio;
+    }
 }
 
 /**
@@ -310,6 +316,7 @@ void UMLWidget::init()
     }
 
     m_resizable = true;
+    m_fixedAspectRatio = false;
 
     m_selected = false;
     m_startMove = false;
@@ -322,7 +329,9 @@ void UMLWidget::init()
     connect(m_scene, SIGNAL(sigRemovePopupMenu()), this, SLOT(slotRemovePopupMenu()));
     connect(m_scene, SIGNAL(sigClearAllSelected()), this, SLOT(slotClearAllSelected()));
 
-    connect(m_scene, SIGNAL(sigColorChanged(Uml::IDType)), this, SLOT(slotColorChanged(Uml::IDType)));
+    connect(m_scene, SIGNAL(sigFillColorChanged(Uml::IDType)), this, SLOT(slotFillColorChanged(Uml::IDType)));
+    connect(m_scene, SIGNAL(sigLineColorChanged(Uml::IDType)), this, SLOT(slotLineColorChanged(Uml::IDType)));
+    connect(m_scene, SIGNAL(sigTextColorChanged(Uml::IDType)), this, SLOT(slotTextColorChanged(Uml::IDType)));
     connect(m_scene, SIGNAL(sigLineWidthChanged(Uml::IDType)), this, SLOT(slotLineWidthChanged(Uml::IDType)));
 
     m_pObject = NULL;
@@ -337,14 +346,14 @@ void UMLWidget::init()
 void UMLWidget::slotMenuSelection(QAction* action)
 {
     QColor newColor;
-    const WidgetBase::WidgetType wt = m_Type;
+    const WidgetBase::WidgetType wt = m_baseType;
     UMLWidget* widget = 0; // use for select the first object properties (fill, line color)
 
     ListPopupMenu::MenuType sel = m_pMenu->getMenuType(action);
     switch (sel) {
     case ListPopupMenu::mt_Rename:
         m_doc->renameUMLObject(m_pObject);
-        // adjustAssocs( getX(), getY() );//adjust assoc lines
+        // adjustAssocs( x(), y() );  // adjust assoc lines
         break;
 
     case ListPopupMenu::mt_Delete:
@@ -369,7 +378,7 @@ void UMLWidget::slotMenuSelection(QAction* action)
         } else {
             uWarning() << "making properties dialog for unknown widget type";
         }
-        // adjustAssocs( getX(), getY() );//adjust assoc lines
+        // adjustAssocs( x(), y() );  // adjust assoc lines
         break;
 
     case ListPopupMenu::mt_Line_Color:
@@ -428,7 +437,7 @@ void UMLWidget::slotMenuSelection(QAction* action)
     case ListPopupMenu::mt_Change_Font:
     case ListPopupMenu::mt_Change_Font_Selection: {
         QFont font = UMLWidget::font();
-        if (KFontDialog::getFont(font, KFontChooser::NoDisplayFlags, m_scene)) {
+        if (KFontDialog::getFont(font, KFontChooser::NoDisplayFlags, m_scene->view())) {
             UMLApp::app()->executeCommand(new CmdChangeFontSelection(m_doc, m_scene, font));
         }
     }
@@ -478,7 +487,8 @@ void UMLWidget::slotMenuSelection(QAction* action)
 }
 
 /**
- * Captures when another widget moves if it is link to it that signal.
+ * Captures when another widget moves if this widget is linked to it.
+ * @see sigWidgetMoved
  *
  * @param id The id of object behind the widget.
  */
@@ -491,24 +501,54 @@ void UMLWidget::slotWidgetMoved(Uml::IDType /*id*/)
  *
  * @param sceneID The id of the object behind the widget.
  */
-void UMLWidget::slotColorChanged(Uml::IDType viewID)
+void UMLWidget::slotFillColorChanged(Uml::IDType viewID)
 {
     //only change if on the diagram concerned
-    if (m_scene->getID() != viewID) {
+    if (m_scene->ID() != viewID) {
         return;
     }
     if (m_usesDiagramFillColor) {
         m_FillColor = m_scene->fillColor();
     }
-    if (m_usesDiagramLineColor) {
-        m_LineColor = m_scene->lineColor();
-    }
     if (m_usesDiagramUseFillColor) {
         m_useFillColor = m_scene->useFillColor();
     }
     update();
 }
 
+/**
+ * Captures a text color change signal.
+ *
+ * @param sceneID The id of the object behind the widget.
+ */
+void UMLWidget::slotTextColorChanged(Uml::IDType viewID)
+{
+    //only change if on the diagram concerned
+    if (m_scene->ID() != viewID)
+        return;
+    setTextColor( m_scene->textColor() );
+    update();
+}
+
+
+/**
+ * Captures a line color change signal.
+ *
+ * @param sceneID The id of the object behind the widget.
+ */
+void UMLWidget::slotLineColorChanged(Uml::IDType viewID)
+{
+    //only change if on the diagram concerned
+    if (m_scene->ID() != viewID)
+        return;
+
+    if (m_usesDiagramLineColor) {
+        m_LineColor = m_scene->lineColor();
+        setLineColor( m_LineColor );
+    }
+    update();
+}
+
 /**
  * Captures a linewidth change signal.
  *
@@ -517,7 +557,7 @@ void UMLWidget::slotColorChanged(Uml::IDType viewID)
 void UMLWidget::slotLineWidthChanged(Uml::IDType viewID)
 {
     //only change if on the diagram concerned
-    if (m_scene->getID() != viewID) {
+    if (m_scene->ID() != viewID) {
         return;
     }
     if (m_usesDiagramLineWidth) {
@@ -548,6 +588,24 @@ void UMLWidget::setUseFillColor(bool fc)
     update();
 }
 
+/**
+ * Overrides the method from WidgetBase.
+ */
+void UMLWidget::setTextColorcmd(const QColor &color)
+{
+    WidgetBase::setTextColor(color);
+    update();
+}
+
+/**
+ * Overrides the method from WidgetBase.
+ */
+void UMLWidget::setTextColor(const QColor &color)
+{
+    UMLApp::app()->executeCommand(new CmdChangeTextColor(this, color));
+    update();
+}
+
 /**
  * Overrides the method from WidgetBase.
  */
@@ -613,7 +671,9 @@ void UMLWidget::drawSelected(QPainter * p, int offsetX, int offsetY)
     p->fillRect(offsetX + w - s, offsetY, s, s, brush);
 
     // Draw the resize anchor in the lower right corner.
-    if (m_resizable) {
+    // Don't draw it if the widget is so small that the
+    // resize anchor would cover up most of the widget.
+    if (m_resizable && w * h > (s*3) * (s*3)) {
         brush.setColor(Qt::red);
         const int right = offsetX + w;
         const int bottom = offsetY + h;
@@ -633,7 +693,7 @@ void UMLWidget::drawSelected(QPainter * p, int offsetX, int offsetY)
  */
 bool UMLWidget::activate(IDChangeLog* /*ChangeLog  = 0 */)
 {
-    if (widgetHasUMLObject(m_Type) && m_pObject == NULL) {
+    if (widgetHasUMLObject(m_baseType) && m_pObject == NULL) {
         m_pObject = m_doc->findObjectById(m_nId);
         if (m_pObject == NULL) {
             uError() << "cannot find UMLObject with id=" << ID2STR(m_nId);
@@ -641,26 +701,26 @@ bool UMLWidget::activate(IDChangeLog* /*ChangeLog  = 0 */)
         }
     }
     setFont(m_Font);
-    setSize(getWidth(), getHeight());
+    setSize(width(), height());
     m_activated = true;
     updateComponentSize();
     if (m_scene->getPaste()) {
         FloatingTextWidget * ft = 0;
         QPoint point = m_scene->getPastePoint();
-        int x = point.x() + getX();
-        int y = point.y() + getY();
+        int x = point.x() + this->x();
+        int y = point.y() + this->y();
         x = x < 0 ? 0 : x;
         y = y < 0 ? 0 : y;
         if (m_scene->type() == Uml::DiagramType::Sequence) {
             switch (baseType()) {
             case WidgetBase::wt_Object:
             case WidgetBase::wt_Precondition :
-                setY(getY());
+                setY(this->y());
                 setX(x);
                 break;
 
             case WidgetBase::wt_Message:
-                setY(getY());
+                setY(this->y());
                 setX(x);
                 break;
 
@@ -668,10 +728,10 @@ bool UMLWidget::activate(IDChangeLog* /*ChangeLog  = 0 */)
                 ft = static_cast<FloatingTextWidget *>(this);
                 if (ft->textRole() == Uml::TextRole::Seq_Message) {
                     setX(x);
-                    setY(getY());
+                    setY(this->y());
                 } else {
-                    setX(getX());
-                    setY(getY());
+                    setX(this->x());
+                    setY(this->y());
                 }
                 break;
 
@@ -686,8 +746,8 @@ bool UMLWidget::activate(IDChangeLog* /*ChangeLog  = 0 */)
         }
     }//end if pastepoint
     else {
-        setX(getX());
-        setY(getY());
+        setX(this->x());
+        setY(this->y());
     }
     if (m_scene->getPaste())
         m_scene->createAutoAssociations(this);
@@ -758,7 +818,6 @@ void UMLWidget::adjustAssocs(int x, int y)
         // -> return immediately without action
         return;
     }
-    AssociationWidgetListIt assoc_it(m_Assocs);
 
     foreach(AssociationWidget* assocwidget , m_Assocs) {
         assocwidget->saveIdealTextPositions();
@@ -779,12 +838,12 @@ void UMLWidget::adjustUnselectedAssocs(int x, int y)
 {
     foreach(AssociationWidget* assocwidget , m_Assocs) {
 
-        if (!assocwidget->getSelected())
+        if (!assocwidget->isSelected())
             assocwidget->saveIdealTextPositions();
     }
 
     foreach(AssociationWidget* assocwidget , m_Assocs) {
-        if (!assocwidget->getSelected())
+        if (!assocwidget->isSelected())
             assocwidget->widgetMoved(this, x, y);
     }
 }
@@ -796,12 +855,11 @@ void UMLWidget::showPropertiesDialog()
 {
     // will already be selected so make sure docWindow updates the doc
     // back it the widget
-    DocWindow *docwindow = UMLApp::app()->docWindow();
-    docwindow->updateDocumentation(false);
+    umlScene()->updateDocumentation(false);
     QPointer<ClassPropDlg> dlg = new ClassPropDlg((QWidget*)UMLApp::app(), this);
 
     if (dlg->exec()) {
-        docwindow->showDocumentation(umlObject() , true);
+        umlScene()->showDocumentation(umlObject() , true);
         m_doc->setModified(true);
     }
     dlg->close(); //wipe from memory
@@ -830,7 +888,7 @@ ListPopupMenu* UMLWidget::setupPopupMenu(ListPopupMenu* menu)
     m_menuIsEmbedded = false;
     //if in a multi- selection to a specific m_pMenu for that
     // NEW: ask UMLView to count ONLY the widgets and not their floatingtextwidgets
-    int count = m_scene->getSelectCount(true);
+    int count = m_scene->selectedCount(true);
     //a MessageWidget when selected will select its text widget and vice versa
     //so take that into account for popup menu.
 
@@ -846,7 +904,7 @@ ListPopupMenu* UMLWidget::setupPopupMenu(ListPopupMenu* menu)
         unique = m_scene->checkUniqueSelection();
 
     // create the right click context menu
-    m_pMenu = new ListPopupMenu(m_scene, this, multi, unique);
+    m_pMenu = new ListPopupMenu(m_scene->view(), this, multi, unique);
 
     // disable the "view code" menu for simple code generators
     if (UMLApp::app()->isSimpleCodeGeneratorActive())
@@ -887,9 +945,9 @@ int UMLWidget::onWidget(const QPoint & p)
 {
     const int w = width();
     const int h = height();
-    const int left = getX();
+    const int left = x();
     const int right = left + w;
-    const int top = getY();
+    const int top = y();
     const int bottom = top + h;
     if (p.x() < left || p.x() > right ||
             p.y() < top || p.y() > bottom)   // Qt coord.sys. origin in top left corner
@@ -903,8 +961,8 @@ int UMLWidget::onWidget(const QPoint & p)
  */
 void UMLWidget::moveByLocal(int dx, int dy)
 {
-    int newX = getX() + dx;
-    int newY = getY() + dy;
+    int newX = x() + dx;
+    int newY = y() + dy;
     setX(newX);
     setY(newY);
     // uDebug() << "********** x=" << newX << " / y=" << newY;
@@ -926,7 +984,7 @@ void UMLWidget::setPenFromSettings(QPainter & p)
  */
 void UMLWidget::drawShape(QPainter &p)
 {
-    paint(p, getX(), getY());
+    paint(p, x(), y());
 }
 
 /**
@@ -997,9 +1055,9 @@ void UMLWidget::setMaximumSize(UMLSceneValue width, UMLSceneValue height)
  */
 void UMLWidget::setSelected(bool _select)
 {
-    const WidgetBase::WidgetType wt = m_Type;
+    const WidgetBase::WidgetType wt = m_baseType;
     if (_select) {
-        if (m_scene->getSelectCount() == 0) {
+        if (m_scene->selectedCount() == 0) {
             if (widgetHasUMLObject(wt)) {
                 m_scene->showDocumentation(m_pObject, false);
             } else {
@@ -1018,11 +1076,11 @@ void UMLWidget::setSelected(bool _select)
     }
     m_selected = _select;
 
-    const QPoint pos(getX(), getY());
+    const QPoint pos(x(), y());
     UMLWidget *bkgnd = m_scene->widgetAt(pos);
     if (bkgnd && bkgnd != this && _select) {
-        uDebug() << "setting Z to " << bkgnd->getZ() + 1 << ", SelectState: " << _select;
-        setZ(bkgnd->getZ() + 1);
+        uDebug() << "setting Z to " << bkgnd->z() + 1 << ", SelectState: " << _select;
+        setZ(bkgnd->z() + 1);
     } else {
         setZ(m_origZ);
     }
@@ -1052,15 +1110,36 @@ void UMLWidget::setScene(UMLScene * v)
     //remove signals from old view - was probably 0 anyway
     disconnect(m_scene, SIGNAL(sigRemovePopupMenu()), this, SLOT(slotRemovePopupMenu()));
     disconnect(m_scene, SIGNAL(sigClearAllSelected()), this, SLOT(slotClearAllSelected()));
-    disconnect(m_scene, SIGNAL(sigColorChanged(Uml::IDType)), this, SLOT(slotColorChanged(Uml::IDType)));
+    disconnect(m_scene, SIGNAL(sigFillColorChanged(Uml::IDType)), this, SLOT(slotFillColorChanged(Uml::IDType)));
+    disconnect(m_scene, SIGNAL(sigTextColorChanged(Uml::IDType)), this, SLOT(slotTextColorChanged(Uml::IDType)));
     disconnect(m_scene, SIGNAL(sigLineWidthChanged(Uml::IDType)), this, SLOT(slotLineWidthChanged(Uml::IDType)));
     m_scene = v;
     connect(m_scene, SIGNAL(sigRemovePopupMenu()), this, SLOT(slotRemovePopupMenu()));
     connect(m_scene, SIGNAL(sigClearAllSelected()), this, SLOT(slotClearAllSelected()));
-    connect(m_scene, SIGNAL(sigColorChanged(Uml::IDType)), this, SLOT(slotColorChanged(Uml::IDType)));
+    connect(m_scene, SIGNAL(sigFillColorChanged(Uml::IDType)), this, SLOT(slotFillColorChanged(Uml::IDType)));
+    connect(m_scene, SIGNAL(sigTextColorChanged(Uml::IDType)), this, SLOT(slotTextColorChanged(Uml::IDType)));
     connect(m_scene, SIGNAL(sigLineWidthChanged(Uml::IDType)), this, SLOT(slotLineWidthChanged(Uml::IDType)));
 }
 
+/**
+ * Gets the x-coordinate.
+ */
+UMLSceneValue UMLWidget::x() const {
+    return UMLSceneRectItem::x();
+}
+/**
+ * Gets the y-coordinate.
+ */
+UMLSceneValue UMLWidget::y() const {
+    return UMLSceneRectItem::y();
+}
+/**
+ * Gets the z-coordinate.
+ */
+UMLSceneValue UMLWidget::z() const {
+    return UMLSceneRectItem::z();
+}
+
 /**
  * Sets the x-coordinate.
  * Currently, the only class that reimplements this method is
@@ -1068,7 +1147,7 @@ void UMLWidget::setScene(UMLScene * v)
  *
  * @param x The x-coordinate to be set.
  */
-void UMLWidget::setX(int x)
+void UMLWidget::setX(UMLSceneValue x)
 {
     if (!m_ignoreSnapToGrid) {
         x = m_scene->snappedX(x);
@@ -1083,7 +1162,7 @@ void UMLWidget::setX(int x)
  *
  * @param y The y-coordinate to be set.
  */
-void UMLWidget::setY(int y)
+void UMLWidget::setY(UMLSceneValue y)
 {
     if (!m_ignoreSnapToGrid) {
         y = m_scene->snappedX(y);
@@ -1096,9 +1175,9 @@ void UMLWidget::setY(int y)
  *
  * @param z The z-coordinate to be set.
  */
-void UMLWidget::setZ(int z)
+void UMLWidget::setZ(UMLSceneValue z)
 {
-    m_origZ = getZ();
+    m_origZ = this->z();
     UMLSceneItem::setZ(z);
 }
 
@@ -1115,7 +1194,6 @@ void UMLWidget::setName(const QString &strName)
     else
         m_Text = strName;
     updateComponentSize();
-    adjustAssocs(getX(), getY());
 }
 
 /**
@@ -1145,8 +1223,8 @@ void UMLWidget::cleanup()
  */
 void UMLWidget::slotSnapToGrid()
 {
-    setX(getX());
-    setY(getY());
+    setX(x());
+    setY(y());
 }
 
 /**
@@ -1189,22 +1267,22 @@ bool UMLWidget::getIgnoreSnapToGrid() const
 
 /**
  * Sets the size.
- * If m_scene->getSnapComponentSizeToGrid() is true, then
+ * If m_scene->snapComponentSizeToGrid() is true, then
  * set the next larger size that snaps to the grid.
  */
 void UMLWidget::setSize(int width, int height)
 {
     // snap to the next larger size that is a multiple of the grid
     if (!m_ignoreSnapComponentSizeToGrid
-            && m_scene->getSnapComponentSizeToGrid()) {
+            && m_scene->snapComponentSizeToGrid()) {
         // integer divisions
-        int numX = width / m_scene->getSnapX();
-        int numY = height / m_scene->getSnapY();
+        int numX = width / m_scene->snapX();
+        int numY = height / m_scene->snapY();
         // snap to the next larger valid value
-        if (width > numX * m_scene->getSnapX())
-            width = (numX + 1) * m_scene->getSnapX();
-        if (height > numY * m_scene->getSnapY())
-            height = (numY + 1) * m_scene->getSnapY();
+        if (width > numX * m_scene->snapX())
+            width = (numX + 1) * m_scene->snapX();
+        if (height > numY * m_scene->snapY())
+            height = (numY + 1) * m_scene->snapY();
     }
 
     UMLSceneRectItem::setSize(width, height);
@@ -1219,7 +1297,7 @@ void UMLWidget::updateComponentSize()
         return;
     QSize size = minimumSize();
     setSize(size.width(), size.height());
-    adjustAssocs(getX(), getY());    // adjust assoc lines
+    adjustAssocs(x(), y());    // adjust assoc lines
 }
 
 /**
@@ -1228,12 +1306,15 @@ void UMLWidget::updateComponentSize()
  */
 void UMLWidget::clipSize()
 {
-    int width = getWidth();
-    int height = getHeight();
-    constrain(width, height);
-    setSize(width, height);
+    int clipWidth = width();
+    int clipHeight = height();
+    constrain(clipWidth, clipHeight);
+    setSize(clipWidth, clipHeight);
 }
 
+/**
+ * Template Method, override this to set the default font metric.
+ */
 void UMLWidget::setDefaultFontMetrics(UMLWidget::FontType fontType)
 {
     setupFontType(m_Font, fontType);
@@ -1287,6 +1368,9 @@ void UMLWidget::setupFontType(QFont &font, UMLWidget::FontType fontType)
     }
 }
 
+/**
+ * Template Method, override this to set the default font metric.
+ */
 void UMLWidget::setDefaultFontMetrics(UMLWidget::FontType fontType, QPainter &painter)
 {
     setupFontType(m_Font, fontType);
@@ -1294,6 +1378,10 @@ void UMLWidget::setDefaultFontMetrics(UMLWidget::FontType fontType, QPainter &pa
     setFontMetrics(fontType, painter.fontMetrics());
 }
 
+/**
+ * Returns the font metric used by this object for Text
+ * which uses bold/italic fonts.
+ */
 QFontMetrics &UMLWidget::getFontMetrics(UMLWidget::FontType fontType)
 {
     if (m_pFontMetrics[fontType] == 0) {
@@ -1302,6 +1390,9 @@ QFontMetrics &UMLWidget::getFontMetrics(UMLWidget::FontType fontType)
     return *m_pFontMetrics[fontType];
 }
 
+/**
+ * Set the font metric to use.
+ */
 void UMLWidget::setFontMetrics(UMLWidget::FontType fontType, QFontMetrics fm)
 {
     delete m_pFontMetrics[fontType];
@@ -1359,11 +1450,11 @@ void UMLWidget::forceUpdateFontMetrics(QPainter *painter)
 /**
  * Set the status of whether to show Stereotype.
  *
- * @param _status   True if stereotype shall be shown.
+ * @param flag   True if stereotype shall be shown.
  */
-void UMLWidget::setShowStereotype(bool _status)
+void UMLWidget::setShowStereotype(bool flag)
 {
-    m_showStereotype = _status;
+    m_showStereotype = flag;
     updateComponentSize();
     update();
 }
@@ -1373,7 +1464,7 @@ void UMLWidget::setShowStereotype(bool _status)
  *
  * @return  True if stereotype is shown.
  */
-bool UMLWidget::getShowStereotype() const
+bool UMLWidget::showStereotype() const
 {
     return m_showStereotype;
 }
@@ -1396,10 +1487,10 @@ void UMLWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
     WidgetBase::saveToXMI(qDoc, qElement);
     qElement.setAttribute("xmi.id", ID2STR(id()));
     qElement.setAttribute("font", m_Font.toString());
-    qElement.setAttribute("x", getX());
-    qElement.setAttribute("y", getY());
-    qElement.setAttribute("width", getWidth());
-    qElement.setAttribute("height", getHeight());
+    qElement.setAttribute("x", x());
+    qElement.setAttribute("y", y());
+    qElement.setAttribute("width", width());
+    qElement.setAttribute("height", height());
     qElement.setAttribute("isinstance", m_isInstance);
     if (!m_instanceName.isEmpty())
         qElement.setAttribute("instancename", m_instanceName);
